==> guymager_0.6.7.orig.tar.gz: guymager-0.6.7/table.h <==
// ****************************************************************************
//  Project:        GUYMAGER
// ****************************************************************************
//  Programmer:     Guy Voncken
//                  Police Grand-Ducale
//                  Service de Police Judiciaire
//                  Section Nouvelles Technologies
// ****************************************************************************
//  Module:         The table widget (central widget of the application)
// ****************************************************************************

// Copyright 2008, 2009, 2010, 2011 Guy Voncken
//
// This file is part of guymager.
//
// guymager is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 2 of the License, or
// (at your option) any later version.
//
// guymager is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with guymager. If not, see <http://www.gnu.org/licenses/>.

#ifndef __TABLE_H__
#define __TABLE_H__

#include <QtGui>      //lint !e537 Repeated include

#ifndef __COMMON_H__
   #include "common.h"
#endif

#ifndef __DEVICE_H__
  #include "device.h"
#endif

class t_TableLocal;
class t_MainWindow;

class t_Table: public QTableView
{
   Q_OBJECT

   public:
      t_Table ();
      t_Table (QWidget *pParent, t_MainWindow *pMainWindow, t_pDeviceList pDeviceList);
     ~t_Table ();

      APIRET AbortAllAcquisitions (void);
      APIRET GetDeviceUnderCursor (t_pDevice &pDevice);

   private:
      APIRET ShowDeviceInfo            (t_pcDevice pDevice);
      APIRET StartAcquisition          (t_pDevice  pDevice, bool Clone);
      APIRET AbortAcquisition0         (t_pDevice  pDevice);
      APIRET AbortAcquisition          (t_pDevice  pDevice);
      APIRET InfoAcquisitionStart      (t_pDevice  pDevice);
      APIRET InfoAcquisitionBadSectors (t_pDevice  pDevice, bool Verify);
      APIRET InfoAcquisitionEnd        (t_pDevice  pDevice);
      APIRET WakeWaitingThreads        (t_pDevice  pDevice);
      APIRET FinaliseThreadStructs     (t_pDevice  pDevice);

   protected:
      void   contextMenuEvent          (QContextMenuEvent *pEvent);

   private slots:
      void SlotMouseClick             (const QModelIndex & index);
      void SlotThreadReadFinished     (t_pDevice pDevice);
      void SlotThreadWriteFinished    (t_pDevice pDevice);
      void SlotThreadHashFinished     (t_pDevice pDevice);
      void SlotThreadCompressFinished (t_pDevice pDevice, int ThreadNr);
      void SlotThreadWriteWakeThreads (t_pDevice pDevice);

   signals:
      void SignalDeviceSelected       (t_pDevice pDevice);
      void SignalAllAcquisitionsEnded (void);

   private:
      t_TableLocal *pOwn;
};

typedef t_Table *t_pTable;


// ------------------------------------
//             Error codes
// ------------------------------------

   #ifdef __MODULES_H__
      enum
      {
         ERROR_TABLE_INVALID_ACTION = ERROR_BASE_TABLE + 1,
         ERROR_TABLE_THREADREAD_ALREADY_RUNNING,
         ERROR_TABLE_THREADHASH_ALREADY_RUNNING,
         ERROR_TABLE_THREADWRITE_ALREADY_RUNNING,
         ERROR_TABLE_THREADCOMPRESS_ALREADY_RUNNING,
         ERROR_TABLE_THREADREAD_DOESNT_EXIT,
         ERROR_TABLE_FIFO_EXISTS,
         ERROR_TABLE_CONSTRUCTOR_NOT_SUPPORTED,
         ERROR_TABLE_INVALID_FORMAT
      };
   #endif

#endif

==> guymager_0.7.4.orig.tar.gz: guymager-0.7.4/table.h <==
// ****************************************************************************
//  Project:        GUYMAGER
// ****************************************************************************
//  Programmer:     Guy Voncken
//                  Police Grand-Ducale
//                  Service de Police Judiciaire
//                  Section Nouvelles Technologies
// ****************************************************************************
//  Module:         The table widget (central widget of the application)
// ****************************************************************************

// Copyright 2008, 2009, 2010, 2011, 2012, 2013, 2014 Guy Voncken
//
// This file is part of guymager.
//
// guymager is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 2 of the License, or
// (at your option) any later version.
//
// guymager is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with guymager. If not, see <http://www.gnu.org/licenses/>.

#ifndef __TABLE_H__
#define __TABLE_H__

#include <QtGui>      //lint !e537 Repeated include

#include "common.h"
#include "device.h"
#include "threadwrite.h"

class t_TableLocal;
class t_MainWindow;

class t_Table: public QTableView
{
   Q_OBJECT

   public:
      t_Table ();
      t_Table (QWidget *pParent, t_MainWindow *pMainWindow, t_pDeviceList pDeviceList);
     ~t_Table ();

      APIRET AbortAllAcquisitions (void);
      APIRET GetDeviceUnderCursor (t_pDevice &pDevice);

   private:
      APIRET ShowDeviceInfo            (t_pcDevice pDevice);
      APIRET ShowAcquisitionDialog     (t_pDevice  pDevice, bool Clone);
      APIRET StartAcquisition          (t_pDevice  pDevice);
      APIRET AbortAcquisition0         (t_pDevice  pDevice);
      APIRET AbortAcquisition          (t_pDevice  pDevice);
      APIRET InfoAcquisitionStart      (t_pAcquisition pAcquisition);
      APIRET InfoAcquisitionBadSectors (t_pAcquisition pAcquisition, bool Verify);
      APIRET InfoAcquisitionEnd0       (t_pAcquisition pAcquisition);
      APIRET InfoAcquisitionEnd        (t_pAcquisition pAcquisition);
      APIRET ThreadWriteFinished       (t_pDevice  pDevice, t_pThreadWrite *ppThreadWrite);
      APIRET WakeWaitingThreads        (t_pDevice  pDevice);
      APIRET FinaliseThreadStructs     (t_pDevice  pDevice);
      APIRET RescheduleJobs            (void);

   protected:
      void   contextMenuEvent          (QContextMenuEvent *pEvent);

   private slots:
      void SlotMouseClick             (const QModelIndex & index);
      void SlotThreadReadFinished     (t_pDevice pDevice);
      void SlotThreadWrite1Finished   (t_pDevice pDevice);
      void SlotThreadWrite2Finished   (t_pDevice pDevice);
      void SlotThreadHashFinished     (t_pDevice pDevice);
      void SlotThreadCompressFinished (t_pDevice pDevice, int ThreadNr);
      void SlotThreadWriteWakeThreads (t_pDevice pDevice);
      void SlotInvalidFreeHandle      (t_pDevice pDevice);

  signals:
      void SignalDeviceSelected       (t_pDevice pDevice);
      void SignalAllAcquisitionsEnded (void);

   private:
      t_TableLocal *pOwn;
};

typedef t_Table *t_pTable;


// ------------------------------------
//             Error codes
// ------------------------------------

   #ifdef __MODULES_H__
      enum
      {
         ERROR_TABLE_INVALID_ACTION = ERROR_BASE_TABLE + 1,
         ERROR_TABLE_THREADREAD_ALREADY_RUNNING,
         ERROR_TABLE_THREADHASH_ALREADY_RUNNING,
         ERROR_TABLE_THREADWRITE_ALREADY_RUNNING,
         ERROR_TABLE_THREADCOMPRESS_ALREADY_RUNNING,
         ERROR_TABLE_THREADREAD_DOESNT_EXIT,
         ERROR_TABLE_FIFO_EXISTS,
         ERROR_TABLE_CONSTRUCTOR_NOT_SUPPORTED,
         ERROR_TABLE_INVALID_FORMAT,
         ERROR_TABLE_INVALID_DIALOG_CODE,
         ERROR_TABLE_INVALID_FREE_HANDLE
      };
   #endif

#endif
